/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DeployableAnalyserTracker.java 5988 2011-09-28 19:14:39Z cazauxj $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.ee.deploy.impl.helper;

import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.util.tracker.ServiceTracker;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * DeployerHelper tracker
 * @Jeremy Cazaux
 */
public class DeployableAnalyserTracker {

    /**
     * The service tracker
     */
    private ServiceTracker serviceTracker;

    /**
     * The logger
     */
    private static Log logger = LogFactory.getLog(DeployableHelperComponent.class);

    /**
     * The BundleContext
     */
    private BundleContext bundleContext;

    /**
     *  LDAP filter for OSGi ServiceTracker
     */
    public static String IDEPLOYABLE_ANALYSER_FILTER = "(&(objectClass=org.ow2.util.ee.deploy.api.helper.IDeployableAnalyser))";

    /**
     * Start the service tracker
     */
    public void start() {

        try {
            this.serviceTracker = new ServiceTracker(
                    bundleContext,
                    bundleContext.createFilter(IDEPLOYABLE_ANALYSER_FILTER),
                    (ServiceTrackerCustomizer) null
            );
        } catch (InvalidSyntaxException e) {
            logger.error("Cannot create filter .", e);
        }
        this.serviceTracker.open();
    }


    /**
     * Close the service tracker
     */
    public void stop() {
        this.serviceTracker.close();
    }

    /**
     * Default constructor
     */
    public DeployableAnalyserTracker(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    /**
     * @return IDeployableAnalyser services
     */
    public Object[] getServices() {
        return this.serviceTracker.getServices();
    }

}
